@@ -197,9 +197,9 @@ class rsa_decrypt(ApiviewDecorator):
     
     def main(self, _django_apiview_request, func):
         if self.field in _django_apiview_request.data:
-            field_value = _django_apiview_request.data[field]
+            field_value = _django_apiview_request.data[self.field]
             field_data = rsautils.smart_get_binary_data(field_value)
-            plain_data = rsautils.decrypt(field_data, private_key)
+            plain_data = rsautils.decrypt(field_data, self.private_key)
             plain_text = plain_data.decode("utf-8")
             view.data[field] = plain_text
         return super().main(_django_apiview_request, func)
